==> plotly-3.1.1-py2.py3-none-any.whl: plotly/validators/histogram/__init__.py <==
from ._ysrc import YsrcValidator
from ._ycalendar import YcalendarValidator
from ._ybins import YBinsValidator
from ._yaxis import YAxisValidator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xcalendar import XcalendarValidator
from ._xbins import XBinsValidator
from ._xaxis import XAxisValidator
from ._x import XValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uid import UidValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._orientation import OrientationValidator
from ._opacity import OpacityValidator
from ._nbinsy import NbinsyValidator
from ._nbinsx import NbinsxValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._histnorm import HistnormValidator
from ._histfunc import HistfuncValidator
from ._error_y import ErrorYValidator
from ._error_x import ErrorXValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._cumulative import CumulativeValidator
from ._autobiny import AutobinyValidator
from ._autobinx import AutobinxValidator

==> plotly-3.7.0rc1-py2.py3-none-any.whl: plotly/validators/histogram/__init__.py <==
from ._ysrc import YsrcValidator
from ._ycalendar import YcalendarValidator
from ._ybins import YBinsValidator
from ._yaxis import YAxisValidator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xcalendar import XcalendarValidator
from ._xbins import XBinsValidator
from ._xaxis import XAxisValidator
from ._x import XValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uirevision import UirevisionValidator
from ._uid import UidValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._orientation import OrientationValidator
from ._opacity import OpacityValidator
from ._offsetgroup import OffsetgroupValidator
from ._nbinsy import NbinsyValidator
from ._nbinsx import NbinsxValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hovertemplatesrc import HovertemplatesrcValidator
from ._hovertemplate import HovertemplateValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._histnorm import HistnormValidator
from ._histfunc import HistfuncValidator
from ._error_y import ErrorYValidator
from ._error_x import ErrorXValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._cumulative import CumulativeValidator
from ._autobiny import AutobinyValidator
from ._autobinx import AutobinxValidator
from ._alignmentgroup import AlignmentgroupValidator
